@@ -4,7 +4,7 @@
 // See file LICENSE for details and terms of copying.
 
 #import "PplObserverSwarm.h"
-#import <simtoolsgui/ActiveGraph.h>
+#import <analysis.h> // ActiveGraph
 #import <gui.h>
 
 // implementation of sample graphical interface for models.
