@@ -128,7 +128,7 @@ VNneighbor * vnneighbor;
       //        I suspect that when the String object gets its
       //        zone, that zone is not cleared.  Since everything
       //        is added to the string by address and chars are 8-bits
-      //        the setC and appendC have to be smart enough to throw
+      //        the setC and catC have to be smart enough to throw
       //        away the part of the word that isn't relevant.
       //        Must be an endian problem.
 #ifdef linux
@@ -153,7 +153,7 @@ VNneighbor * vnneighbor;
       for (incj = 1; incj <= namesize; incj++)
         {
           temp_char = [uniformIntRand getIntegerWithMin:'a' withMax:'z'];
-          [name appendC: (char *) &temp_char];
+          [name catC: (char *) &temp_char];
         }
 
       // the null topic is how undesirable communication is for this person
