@@ -4,9 +4,9 @@
 // See file LICENSE for details and terms of copying.
 
 #import <simtoolsgui/GUISwarm.h>
-#import <simtoolsgui.h>
 #import <analysis.h>
 #import <gui.h>
+#import <space.h>
 #import "PplModelSwarm.h"
 
 // Sample graphical interface swarm for models.
@@ -28,12 +28,12 @@
   id <ActiveGraph> pplLeftGrapher;
 
   // add the number of friends averager
-  EZGraph *avgFriendGraph;
+  id <EZGraph> avgFriendGraph;
 
   // add the space viewer objects
   id <Colormap> colormap;
   id <ZoomRaster> worldRaster;
-  Object2dDisplay *pplDisplay;
+  id <Object2dDisplay> pplDisplay;
 }
 
 + createBegin: aZone;
