@@ -3,13 +3,14 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject.h>
-#import <swarmobject/Swarm.h>
+#import <objectbase.h>
+#import <objectbase/Swarm.h>
 #import "Counter.h"
 
 // Sample model swarm - in this case, create one counter and schedule it.
 
-@interface TemplateModelSwarm : Swarm {
+@interface TemplateModelSwarm: Swarm
+{
   // MODIFY: add your own simulation parameters
   int increment;
 
@@ -17,16 +18,16 @@
   id modelSchedule;
 
   // MODIFY: add your own model objects.  
-  Counter * counter;
+  Counter *counter;
 }
 
 // MODIFY: add access methods for what agents are visible.
--(Counter *)getCounter;
+- (Counter *)getCounter;
 
-+createBegin: (id) aZone;
--createEnd;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- createEnd;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
