@@ -5,6 +5,7 @@
 
 #import "ModelSwarm.h"
 #import <simtoolsgui/GUISwarm.h>
+#import <objectbase/SwarmObject.h>
 #import <objectbase.h>
 #import <analysis.h>
 
@@ -56,7 +57,7 @@
 
  // Display objects, widgets, etc.
 
-  EZGraph *resultGraph;				// graphing widget
+  id <EZGraph> resultGraph;				// graphing widget
   id <ProbeMap> modelProbeMap;			// the ProbeMap for the modelSwarm
 }
 
